@@ -55,6 +55,8 @@ class SocksProxyConnection:
 
 			self.target.proxy.target.endpoint_ip = self.target.ip
 			self.target.proxy.target.endpoint_port = int(self.target.port)
+			self.target.proxy.target.endpoint_timeout = int(self.target.timeout)
+			self.target.proxy.target.timeout = int(self.target.timeout)
 
 			self.client = SOCKSClient(comms, self.target.proxy.target, self.target.proxy.auth)
 			self.proxy_task = asyncio.create_task(self.client.run())
